@@ -151,7 +151,6 @@ class TamingDecoder(ImageGenerator):
 
         gen_img_list = []
         z_logits_list = []
-
         for step in range(num_generations):
             loss = 0
 
@@ -189,8 +188,6 @@ class TamingDecoder(ImageGenerator):
                     x_rec[0])
                 gen_img_list.append(x_rec_img)
 
-                # x_rec_img.save(f"generations/{step}.png")
-
             torch.cuda.empty_cache()
 
         return gen_img_list, z_logits_list
@@ -222,15 +219,17 @@ class TamingDecoder(ImageGenerator):
                     x_rec[0])
                 gen_img_list.append(x_rec_img)
 
+                torch.cuda.empty_cache()
+
         return gen_img_list
 
 
 if __name__ == '__main__':
-    prompt = "The mexican life, painted by Diego Rivera"
+    prompt = "Pokemon of type fire"
     lr = 0.5
     img_save_freq = 1
-    num_generations = 200
-    num_random_crops = 20
+    num_generations = 64
+    num_random_crops = 64
     img_batch = None
 
     taming_decoder = TamingDecoder()
@@ -242,3 +241,20 @@ if __name__ == '__main__':
         num_random_crops=num_random_crops,
         img_batch=img_batch,
     )
+
+    _gen_img_list, z_logits_list_ = taming_decoder.generate_from_prompt(
+        prompt="Pokemon of type grass",
+        lr=lr,
+        img_save_freq=img_save_freq,
+        num_generations=num_generations,
+        num_random_crops=num_random_crops,
+        img_batch=img_batch,
+    )
+
+    z_logits_interp_list = [z_logits_list[-1], z_logits_list_[-1]]
+
+    duration_list = [0.7] * len(z_logits_interp_list)
+    interpolate_img_list = taming_decoder.interpolate(
+        z_logits_list=z_logits_interp_list,
+        duration_list=duration_list,
+    )
